summaryrefslogtreecommitdiffstats
path: root/khtml/khtml_part.h
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/khtml_part.h')
-rw-r--r--khtml/khtml_part.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/khtml/khtml_part.h b/khtml/khtml_part.h
index af8a1695d..95cd952b1 100644
--- a/khtml/khtml_part.h
+++ b/khtml/khtml_part.h
@@ -243,10 +243,10 @@ public:
* rendered in. You can specify two different parent objects for a
* KHTMLPart, one parent for the KHTMLPart document and on parent
* for the KHTMLView. If the second @p parent argument is 0L, then
* @p parentWidget is used as parent for both objects, the part and
* the view.
*/
- KHTMLPart( TQWidget *parentWidget = 0, const char *widgetname = 0,
+ KHTMLPart( TQWidget *tqparentWidget = 0, const char *widgetname = 0,
TQObject *parent = 0, const char *name = 0, GUIProfile prof = DefaultGUI );
KHTMLPart( KHTMLView *view, TQObject *parent = 0, const char *name = 0, GUIProfile prof = DefaultGUI );
@@ -1168,7 +1168,7 @@ protected:
* to be a object of your derived type, in which case you should return a new instance for
* the mimetype 'text/html' .
*/
- virtual KParts::ReadOnlyPart *createPart( TQWidget *parentWidget, const char *widgetName,
+ virtual KParts::ReadOnlyPart *createPart( TQWidget *tqparentWidget, const char *widgetName,
TQObject *parent, const char *name,
const TQString &mimetype, TQString &serviceName,
TQStringList &serviceTypes, const TQStringList &params);
@@ -243,10 +243,10 @@ public:
* KHTMLPart, one parent for the KHTMLPart document and on parent
* for the KHTMLView. If the second @p parent argument is 0L, then
- * @p parentWidget is used as parent for both objects, the part and
+ * @p tqparentWidget is used as parent for both objects, the part and
* the view.
*/